##  Overview
To get started with the Integration API, use the built-in user interface in the Integration API section of the administration area. Here, you can:
  * View, modify, and run preconfigured processors.
  * Create and manage processors.
  * Complete test runs without the risk of overwriting or deleting workspace data.
  * Run processors to import or export data to and from your workspace.
  * Get the data model of your workspace in JSON format, which includes the keys of meta model attributes.


![Integration API Page in the Administration Area](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275516587a441014ae78f8daf95aeacd_LowRes.png)
Integration API Page in the Administration Area
